==> pegasus-merchandise-api-1.4.25-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsCustomizeImageWordContentVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * 文字内容定制
 */
public class PcsCustomizeImageWordContentVO implements Serializable {

  private static final long serialVersionUID = -8952267697376678344L;

  //前端是否显示
  private boolean whetherShow;

  private String icon;

  private String iconText;

  private Short wordLimit;

  private List<PcsCustomizeContentTypeVO> customizeContentTypeList;

  //英文字体
  private String englishFont;

  //数字字体
  private String digitalFont;


  public String getIconText() {
    return iconText;
  }

  public void setIconText(String iconText) {
    this.iconText = iconText;
  }

  public boolean isWhetherShow() {
    return whetherShow;
  }

  public void setWhetherShow(boolean whetherShow) {
    this.whetherShow = whetherShow;
  }

  public String getIcon() {
    return icon;
  }

  public void setIcon(String icon) {
    this.icon = icon;
  }

  public Short getWordLimit() {
    return wordLimit;
  }

  public void setWordLimit(Short wordLimit) {
    this.wordLimit = wordLimit;
  }

  public List<PcsCustomizeContentTypeVO> getCustomizeContentTypeList() {
    return customizeContentTypeList;
  }

  public void setCustomizeContentTypeList(List<PcsCustomizeContentTypeVO> customizeContentTypeList) {
    this.customizeContentTypeList = customizeContentTypeList;
  }

  public String getEnglishFont() {
    return englishFont;
  }

  public void setEnglishFont(String englishFont) {
    this.englishFont = englishFont;
  }

  public String getDigitalFont() {
    return digitalFont;
  }

  public void setDigitalFont(String digitalFont) {
    this.digitalFont = digitalFont;
  }
}

==> pegasus-merchandise-api-3.0.1-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsCustomizeImageWordContentVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * 文字内容定制
 */
public class PcsCustomizeImageWordContentVO implements Serializable {

  private static final long serialVersionUID = -8952267697376678344L;

  //前端是否显示
  private boolean whetherShow;

  private String icon;

  private String iconText;

  private Short wordLimit;

  private List<PcsCustomizeContentTypeVO> customizeContentTypeList;

  //英文字体
  private String englishFont;

  //数字字体
  private String digitalFont;

  //打印模板类型 （1：蜡烛模板，2：散香器模板）
  private Short printTemplateType;


  public String getIconText() {
    return iconText;
  }

  public void setIconText(String iconText) {
    this.iconText = iconText;
  }

  public boolean isWhetherShow() {
    return whetherShow;
  }

  public void setWhetherShow(boolean whetherShow) {
    this.whetherShow = whetherShow;
  }

  public String getIcon() {
    return icon;
  }

  public void setIcon(String icon) {
    this.icon = icon;
  }

  public Short getWordLimit() {
    return wordLimit;
  }

  public void setWordLimit(Short wordLimit) {
    this.wordLimit = wordLimit;
  }

  public List<PcsCustomizeContentTypeVO> getCustomizeContentTypeList() {
    return customizeContentTypeList;
  }

  public void setCustomizeContentTypeList(List<PcsCustomizeContentTypeVO> customizeContentTypeList) {
    this.customizeContentTypeList = customizeContentTypeList;
  }

  public String getEnglishFont() {
    return englishFont;
  }

  public void setEnglishFont(String englishFont) {
    this.englishFont = englishFont;
  }

  public String getDigitalFont() {
    return digitalFont;
  }

  public void setDigitalFont(String digitalFont) {
    this.digitalFont = digitalFont;
  }

  public Short getPrintTemplateType() {
    return printTemplateType;
  }

  public void setPrintTemplateType(Short printTemplateType) {
    this.printTemplateType = printTemplateType;
  }
}
